TlsTranscript

Struct TlsTranscript 

pub struct TlsTranscript { /* private fields */ }
A transcript of TLS records sent and received by the prover.

Invariants

  • First record of TlsTranscript::sent or TlsTranscript::recv is the finished record.
  • Records are ordered but records which are not of type ContentType::ApplicationData can be missing.
  • Handshake related fields may be absent.
  • Plaintext of records may be absent.

Implementations

Source

impl TlsTranscript

pub fn builder<'a>() -> TlsTranscriptBuilder<'a>

Returns a builder for TlsTranscript.

pub fn time(&self) -> u64

Returns the start time of the connection.

pub fn version(&self) -> TlsVersion

Returns the TLS protocol version.

pub fn server_signature(&self) -> Option<&ServerSignature>

Returns the signature of the server.

pub fn server_cert_chain(&self) -> Option<&[CertificateDer]>

Returns the certificate chain.

pub fn certificate_binding(&self) -> &CertBinding

Returns the certificate binding.

pub fn sent(&self) -> &[Record]

Returns the sent records.

pub fn recv(&self) -> &[Record]

Returns the received records.

pub fn client_finished(&self) -> &Record

Returns the client finished record.

pub fn cf_vd(&self) -> Option<&[u8]>

Returns the client finished verify data.

pub fn server_finished(&self) -> &Record

Returns the server finished record.

pub fn sf_vd(&self) -> Option<&[u8]>

Returns the server finished verify data.

pub fn cf_hash(&self) -> Option<[u8; 32]>

Returns the client finished hash.

pub fn session_hash(&self) -> Option<[u8; 32]>

Returns the session hash.

The session hash is the SHA-256 digest over the handshake messages from ClientHello up to and including ClientKeyExchange (RFC 7627). It is used to derive the extended master secret.

pub fn sf_hash(&self, cf_vd: &[u8; 12]) -> Option<[u8; 32]>

Returns the server finished hash given the client finished verify data.

pub fn to_transcript(&self) -> Result<Transcript, TlsTranscriptError>

Returns the application data transcript.